@@ -621,24 +621,28 @@ callback_exit (GtkWidget *widget, GdkEvent *event)
       mb = gtk_message_dialog_new (GTK_WINDOW (main_window),
 		      GTK_DIALOG_MODAL,
 		      GTK_MESSAGE_QUESTION,
-		      GTK_BUTTONS_YES_NO,
+		      GTK_BUTTONS_NONE,
 		      _("Exit this game?"),
 		      NULL);
-
+      gtk_dialog_add_buttons (GTK_DIALOG (mb),
+			      GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
+			      GTK_STOCK_QUIT, GTK_RESPONSE_ACCEPT, 
+			      NULL);
       gtk_dialog_set_default_response (GTK_DIALOG (mb),
-		      GTK_RESPONSE_YES);
+		      GTK_RESPONSE_REJECT);
       response = gtk_dialog_run (GTK_DIALOG(mb));
       gtk_widget_destroy (mb);
 
-      if (response == GTK_RESPONSE_YES)
+      if (response == GTK_RESPONSE_REJECT)
       {
-	      callback_exit_with_lose();
-      } else {
-        return TRUE;
+	return TRUE;
       }
+      callback_exit_with_lose();
     }
   else
+  {
     callback_exit_really();
+  }
 }
 
 void
@@ -1213,14 +1217,14 @@ to_destination_auto(void)
 		      _("Congratulations.  You won.\nDo you want to play again?"),
 		      NULL);
 
-      gtk_dialog_run (GTK_DIALOG(mb));
+      response = gtk_dialog_run (GTK_DIALOG(mb));
       gtk_widget_destroy (mb);
 
+      score_add_win();
+      stalled = 1;
+
       if (response == GTK_RESPONSE_YES)
 	      callback_new_really_callback();
-      
-      score_add_win();
-      stalled = 1;
     }
   
 
